@@ -2,11 +2,11 @@
 
 # Copyright (c) 2007-2015 The OpenRC Authors.
 # See the Authors file at the top-level directory of this distribution and
-# https://github.com/OpenRC/openrc/blob/master/AUTHORS
+# https://github.com/OpenRC/openrc/blob/HEAD/AUTHORS
 #
 # This file is part of OpenRC. It is subject to the license terms in
 # the LICENSE file found in the top-level directory of this
-# distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+# distribution and at https://github.com/OpenRC/openrc/blob/HEAD/LICENSE
 # This file may not be copied, modified, propagated, or distributed
 #    except according to the terms contained in the LICENSE file.
 
@@ -38,10 +38,6 @@ ssd_start()
 		service_inactive && _inactive=true
 		mark_service_inactive
 	fi
-	[ -n "$output_logger" ] && 
-		output_logger_arg="--stdout-logger \"$output_logger\""
-	[ -n "$error_logger" ] && 
-		error_logger_arg="--stderr-logger \"$error_logger\""
 	#the eval call is necessary for cases like:
 	# command_args="this \"is a\" test"
 	# to work properly.
@@ -51,8 +47,11 @@ ssd_start()
 		${directory:+--chdir} $directory \
 		${output_log+--stdout} $output_log \
 		${error_log+--stderr} $error_log \
-		${output_logger_arg} \
-		${error_logger_arg} \
+		${output_logger:+--stdout-logger} "$output_logger" \
+		${error_logger:+--stderr-logger} "$error_logger" \
+		${capabilities+--capabilities} "$capabilities" \
+		${secbits:+--secbits} "$secbits" \
+		${no_new_privs:+--no-new-privs} \
 		${procname:+--name} $procname \
 		${pidfile:+--pidfile} $pidfile \
 		${command_user+--user} $command_user \
